# -*- coding: utf-8 -*-
"""
lanyora - A collection of cloud utilities and decorators
"""

__version__ = "0.1.0"
__author__ = "Lanyora"
__email__ = "Lanyora@qq.com"

# 如果你保留导入，确保没有中文字符在注释中
# 或者完全删除导入，让用户从子模块导入
# 从子模块导入功能
from .decorators import timer, retry
from .utils import alert, random_password, open_in_browser

__all__ = [
    "timer", "retry",
    "alert", "random_password", "open_in_browser"
]